OC.L10N.register(
    "files",
    {
    "Added to favorites" : "Bætt í eftirlæti",
    "Removed from favorites" : "Fjarlægt úr eftirlætum",
    "You added {file} to your favorites" : "Þú bættir {file} í eftirlætin þín",
    "You removed {file} from your favorites" : "Þú fjarlægðir {file} úr eftirlætunum þínum",
    "Favorites" : "Eftirlæti",
    "File changes" : "Skráarbreytingar",
    "Created by {user}" : "Búið til af {user}",
    "Changed by {user}" : "Breytt af {user}",
    "Deleted by {user}" : "Eytt af {user}",
    "Restored by {user}" : "Endurheimt af {user}",
    "Renamed by {user}" : "Endurnefnt af {user}",
    "Moved by {user}" : "Fært af {user}",
    "\"remote account\"" : "\"fjartengdur aðgangur\"",
    "You created {file}" : "Þú bjóst til {file}",
    "You created an encrypted file in {file}" : "Þú bjóst til dulritaða skrá í {file}",
    "{user} created {file}" : "{user} bjó til {file}",
    "{user} created an encrypted file in {file}" : "{user} bjó til dulritaða skrá í {file}",
    "{file} was created in a public folder" : "{file} var búin til í opinni möppu",
    "You changed {file}" : "Þú breyttir {file}",
    "You changed an encrypted file in {file}" : "Þú breyttir dulritaðri skrá í {file}",
    "{user} changed {file}" : "{user} breytti {file}",
    "{user} changed an encrypted file in {file}" : "{user} breytti dulritaðri skrá í {file}",
    "You deleted {file}" : "Þú eyddir {file}",
    "You deleted an encrypted file in {file}" : "Þú eyddir dulritaðri skrá í {file}",
    "{user} deleted {file}" : "{user} eyddi {file}",
    "{user} deleted an encrypted file in {file}" : "{user} eyddi dulritaðri skrá í {file}",
    "You restored {file}" : "Þú endurheimtir {file}",
    "{user} restored {file}" : "{user} endurheimti {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Þú endurnefndir {oldfile} (falin) sem {newfile} (falin)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Þú endurnefndir {oldfile} (falin) sem {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Þú endurnefndir {oldfile} sem {newfile} (falin)",
    "You renamed {oldfile} to {newfile}" : "Þú endurnefndir {oldfile} sem {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} endurnefndi {oldfile} (falin) sem {newfile} (falin)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} endurnefndi {oldfile} (falin) sem {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} endurnefndi {oldfile}sem {newfile} (falin)",
    "{user} renamed {oldfile} to {newfile}" : "{user} endurnefndi {oldfile} sem {newfile}",
    "You moved {oldfile} to {newfile}" : "Þú færðir {oldfile} í {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} færði {oldfile} í {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Skrá var bætt við eða hún fjarlægð úr <strong>eftirlætum</strong>",
    "Files" : "Skráaforrit",
    "A file or folder has been <strong>changed</strong>" : "Skjali eða möppu hefur verið <strong>breytt</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Skrá eða möppu í eftirlætum hefur verið <strong>breytt</strong>",
    "Failed to authorize" : "Tókst ekki að auðkenna",
    "Invalid folder path" : "Ógild slóð á möppu",
    "Folder not found" : "Mappa fannst ekki",
    "The file cannot be found" : "Skráin finnst ekki",
    "The destination path does not exist: %1$s" : "Móttökuslóðin er ekki til: %1$s",
    "You do not have permission to create a file at the specified location" : "Þú hefur ekki heimild til að búa til skrá á umbeðnu staðsetningunni",
    "The file could not be converted." : "Ekki var hægt að umbreyta skránni.",
    "Could not get relative path to converted file" : "Ekki tókst að fá afstæða slóð að umbreyttu skránni",
    "Limit must be a positive integer." : "Takmörk verða að vera jákvæð heiltala.",
    "The replacement character may only be a single character." : "Útskiptistafurinn verður að vera eitt staftákn.",
    "Filename sanitization already started." : "Lagfæring skráaheita er þegar hafin.",
    "No filename sanitization in progress." : "Engin lagfæring skráaheita í gangi.",
    "Favorite files" : "Eftirlætisskrár",
    "No favorites" : "Engin eftirlæti",
    "More favorites" : "Fleiri eftirlæti",
    "Accept" : "Samþykkja",
    "Reject" : "Hafna",
    "Incoming ownership transfer from {user}" : "Innkomandi millifærsla eignarhalds frá {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Viltu taka við {path}?\n\nAthugaðu: Millifærsluferlið eftir samþykki getur tekið allt að 1 klukkustund.",
    "Ownership transfer denied" : "Millifærslu eignarhalds hafnað",
    "Your ownership transfer of {path} was denied by {user}." : "Millifærslu eignarhalds á {path} var hafnað af {user}.",
    "Ownership transfer failed" : "Millifærsla eignarhalds mistókst",
    "Your ownership transfer of {path} to {user} failed." : "Millifærsla eignarhalds á {path} frá þér til {user} mistókst.",
    "The ownership transfer of {path} from {user} failed." : "Millifærsla eignarhalds á {path} frá {user} mistókst.",
    "Ownership transfer done" : "Millifærslu eignarhalds er lokið",
    "Your ownership transfer of {path} to {user} has completed." : "Millifærslu eignarhalds á {path} frá þér til {user} er lokið.",
    "The ownership transfer of {path} from {user} has completed." : "Millifærslu eignarhalds á {path} frá {user} er lokið.",
    "in %s" : "í %s",
    "Transferred from %1$s on %2$s" : "Flutt frá %1$s á %2$s",
    "File Management" : "Skráastjórnun",
    "Home" : "Heim",
    "Target folder does not exist any more" : "Markmappan er ekki lengur til",
    "Reload current directory" : "Endurhlaða núverandi möppu",
    "Go to the \"{dir}\" directory" : "Fara í heimamöppu",
    "Current directory path" : "Fyrirliggjandi slóð að möppu",
    "Your have used your space quota and cannot upload files anymore" : "Þú hefur fullnýtt geymslukvótann þinn og getur ekki lengur sent inn skrár",
    "You do not have permission to upload or create files here." : "Þú hefur ekki heimild til að senda inn eða búa til skrár hér.",
    "Drag and drop files here to upload" : "Dragðu og slepptu hér skrám til að senda inn",
    "Favorite" : "Eftirlæti",
    "Back" : "Til baka",
    "Toggle selection for file \"{displayName}\"" : "Víxla vali af/á} fyrir skrána \"{displayName}\"",
    "Toggle selection for folder \"{displayName}\"" : "Víxla vali af/á} fyrir möppuna \"{displayName}\"",
    "File is loading" : "Skrá er að hlaðast inn",
    "Folder is loading" : "Mappan er að hlaðast inn",
    "Filename" : "Skráarheiti",
    "Folder name" : "Nafn möppu",
    "This node is unavailable" : "Þessi hnútur er ekki tiltækur",
    "Another entry with the same name already exists." : "Önnur færsla með sama heiti er þegar til staðar.",
    "Invalid filename." : "Ógilt skráarheiti.",
    "Renamed \"{oldName}\" to \"{newName}\"" : "Endurnefndi \"{oldName}\" sem \"{newName}\"",
    "Rename file" : "Endurnefna skrá",
    "Folder" : "Mappa",
    "Unknown file type" : "Óþekkt skráartegund",
    "{ext} image" : "{ext} mynd",
    "{ext} video" : "{ext} myndskeið",
    "{ext} audio" : "{ext} hljóðskrá",
    "{ext} text" : "{ext} textaskrá",
    "Pending" : "Í bið",
    "Unknown date" : "Óþekkt dagsetning",
    "Clear filter" : "Hreinsa síu",
    "Modified" : "Breytt",
    "Search everywhere" : "Leita allsstaðar",
    "Type" : "Tegund",
    "Active filters" : "Virkar síur",
    "Remove filter" : "Fjarlægja síu",
    "Appearance" : "Útlit",
    "Show hidden files" : "Sýna faldar skrár",
    "Show file type column" : "Sýna dálk fyrir skráategund",
    "Show file extensions" : "Birta skráaendingar",
    "Crop image previews" : "Skera utan af forskoðun mynda",
    "General" : "Almennt",
    "Sort favorites first" : "Raða eftirlætum fremst",
    "Sort folders before files" : "Raða möppum á undan skrám",
    "Default view" : "Sjálfgefin sýn",
    "All files" : "Allar skrár",
    "Personal files" : "Einkaskrár",
    "Additional settings" : "Valfrjálsar stillingar",
    "Actions" : "Aðgerðir",
    "File actions" : "Skráaaðgerðir",
    "Selection" : "Val",
    "Select all files" : "Velja allar skrár",
    "Deselect all" : "Afvelja allt",
    "Select or deselect" : "Velja eða afvelja",
    "Select a range" : "Veldu svið",
    "Navigation" : "Yfirsýn",
    "Go to parent folder" : "Fara í yfirmöppu",
    "Go to file above" : "Fara í skrá fyrir ofan",
    "Go to file below" : "Fara í skrá fyrir neðan",
    "Go left in grid" : "Fara til vinstri í reitum",
    "Go right in grid" : "Fara til hægri í reitum",
    "View" : "Skoða",
    "Toggle grid view" : "Víxla reitasýn af/á",
    "Open file sidebar" : "Opna hliðarspjald skráa",
    "Show those shortcuts" : "Sýna þessa flýtilykla",
    "Warnings" : "Aðvaranir",
    "Warn before changing a file extension" : "Aðvara áður en skráarendingu er breytt",
    "WebDAV URL" : "WebDAV-slóð",
    "How to access files using WebDAV" : "Hvernig á að nálgast skrár í gegnum WebDAV",
    "Total rows summary" : "Samantek á fjölda raða",
    "Toggle selection for all files and folders" : "Víxla vali af/á fyrir allar skrár og möppur",
    "Name" : "Heiti",
    "File type" : "Skráartegund",
    "Size" : "Stærð",
    "{displayName}: failed on some elements" : "{displayName}: mistókst á einhverjum atriðum",
    "{displayName}: done" : "{displayName}: lokið",
    "{displayName}: failed" : "{displayName}: mistókst",
    "(selected)" : "(valið)",
    "List of files and folders." : "Listi yfir skrár og möppur.",
    "You have used your space quota and cannot upload files anymore." : "Þú hefur fullnýtt geymslukvótann þinn og getur ekki lengur sent inn skrár.",
    "Column headers with buttons are sortable." : "Dálkfyrirsagnir með hnöppum eru raðanlegar",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Til að halda sem bestum afköstum er þessi listi ekki myndgerður að fullu. Skrárnar munu birtast eftir því sem farið er í gegnum listann.",
    "File not found" : "Skrá finnst ekki",
    "_{count} selected_::_{count} selected_" : ["{count} valið","{count} valið"],
    "Search everywhere …" : "Leita allsstaðar …",
    "Search here …" : "Leita hér …",
    "Search scope options" : "Valkostir leitarsviðs",
    "Search here" : "Leita hér",
    "Owner" : "Eigandi",
    "{usedQuotaByte} used" : "{usedQuotaByte} notað",
    "{used} of {quota} used" : "{used} af {quota} notað",
    "{relative}% used" : "{relative}% notað",
    "Could not refresh storage stats" : "Gat ekki uppfært tölfræði fyrir geymslurými",
    "Your storage is full, files can not be updated or synced anymore!" : "Geymsluplássið þitt er fullt, ekki er lengur hægt að uppfæra eða samstilla skrár!",
    "Storage information" : "Upplýsingar um gagnageymslu",
    "Storage quota" : "Geymslukvóti",
    "New folder" : "Ný mappa",
    "Create new folder" : "Búa til nýja möppu",
    "This name is already in use." : "Þetta nafn er nú þegar í notkun.",
    "Create" : "Búa til",
    "Files starting with a dot are hidden by default" : "Skrár með heiti sem byrjar á punkti, eru sjálfgefið faldar",
    "Failed to start filename sanitization." : "Mistókst að ræsa lagfæringu skráaheita.",
    "Failed to refresh filename sanitization status." : "Mistókst að endurlesa stöðu á lagfæringum skráaheita.",
    "Filename sanitization in progress." : "Lagfæring skráaheita í gangi.",
    "Currently {processedUsers} of {totalUsers} accounts are already processed." : "Núna eru {processedUsers} af {totalUsers} aðgöngum þegar meðhöndlaðir.",
    "Preparing …" : "Undirbý …",
    "Refresh" : "Endurnýja",
    "All files have been santized for Windows filename support." : "Allar skrár hafa verið lagfærðar með tilliti til stuðnings við Windows-skráaheiti.",
    "Some files could not be sanitized, please check your logs." : "Ekki var hægt að lagfæra sum skráaheiti, skoðaðu atvikaskrárnar þínar.",
    "Sanitization errors" : "Villur við lagfæringu",
    "Not sanitized filenames" : "Ekki lagfærð skráaheiti",
    "Windows filename support has been enabled." : "Stuðningur við Windows-skráaheiti hefur verið virkjaður.",
    "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows." : "Á meðan þetta kemur í veg fyrir að notendur búi til nýjar skrár með óstuddum skráaheitum, þá eru fyrirliggjandi skrár ekki ennþá endurnefndar og gætu þannig skemmt fyrir samstillingu á Windows.",
    "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time." : "Þú getur sett í gang endurnefningu á skrám með ógild skráaheiti, það verður framkvæmt í bakgrunnsferli og gæti tekið nokkra stund.",
    "Please note that this may cause high workload on the sync clients." : "Athugaðu að þetta getur valdið miklu álagi á samstillt biðlaraforrit.",
    "Limit" : "Takmörk",
    "This allows to configure how many users should be processed in one background job run." : "Þetta gerir kleift að stilla hve marga notendur eigi að meðhöndla í einu bakgrunnsferli.",
    "Sanitize filenames" : "Lagfæra skráaheiti",
    "(starting)" : "(byrja)",
    "Fill template fields" : "Fylla inn reiti sniðmáts",
    "Submitting fields …" : "Sendi inn gagnasvið…",
    "Submit" : "Senda inn",
    "Choose a file or folder to transfer" : "Veldu skrá eða möppu til að millifæra",
    "Transfer" : "Færa",
    "Transfer {path} to {userid}" : "Færa {path} til {userid}",
    "Invalid path selected" : "Ógild slóð valin",
    "Unknown error" : "Óþekkt villa",
    "Ownership transfer request sent" : "Beiðni um millifærslu eignarhalds send",
    "Cannot transfer ownership of a file or folder you do not own" : "Ekki er hægt að millifæra eignarhald á skrá eða möppu sem þú átt ekki",
    "Transfer ownership of a file or folder" : "Millifæra eignarhald skráar eða möppu",
    "Choose file or folder to transfer" : "Veldu skrá eða möppu til að millifæra",
    "Change" : "Breyta",
    "New owner" : "Nýr eigandi",
    "Keep {old}" : "Halda {old}",
    "Keep without extension" : "Halda án skráarendingar",
    "Use {new}" : "Nota {new}",
    "Remove extension" : "Fjarlægja skráarendingu",
    "Change file extension" : "Breyta skráarendingu",
    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Sé skráaendingunni breytt úr \"{old}\" yfir í \"{new}\", gæti skráin orðið ólæsileg.",
    "Removing the file extension \"{old}\" may render the file unreadable." : "Sé skráaendingin \"{old}\" fjarlægð, gæti skráin orðið ólæsileg.",
    "Adding the file extension \"{new}\" may render the file unreadable." : "Sé skráaendingunni \"{new}\" bætt við, gæti skráin orðið ólæsileg.",
    "Do not show this dialog again." : "Ekki sýna þennan glugga aftur.",
    "Select file or folder to link to" : "Veldu skrá eða möppu til að tengja í",
    "Choose {file}" : "Veldu {file}",
    "Files settings" : "Stillingar skráaforritsins",
    "Share" : "Deila",
    "Shared by link" : "Deilt með tengli",
    "Shared" : "Sameiginlegt",
    "Switch to list view" : "Skipta yfir í listasýn",
    "Switch to grid view" : "Skipta yfir í reitasýn",
    "The file could not be found" : "Skráin fannst ekki",
    "Upload was cancelled by user" : "Notandi hætti við innsendingu",
    "Not enough free space" : "Ekki nægilegt pláss",
    "Operation is blocked by access control" : "Aðgerðin er hindruð af aðgangsstýringu",
    "Error during upload: {message}" : "Villa við innsendingu: {message}",
    "Error during upload, status code {status}" : "Villa við innsendingu, stöðukóði: {status}",
    "Unknown error during upload" : "Óþekkt villa við innsendingu",
    "Loading current folder" : "Hleð inn núverandi möppu",
    "Retry" : "Reyna aftur",
    "No files in here" : "Engar skrár hér",
    "Upload some content or sync with your devices!" : "Sendu inn eitthvað efni eða samstilltu við tækin þín!",
    "Go back" : "Fara til baka",
    "Views" : "Skoðun",
    "Your files" : "Skrárnar þínar",
    "Open in files" : "Opna í skráaforritinu",
    "File cannot be accessed" : "Skráin er ekki aðgengileg",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Skráin fannst ekki eða að þú hefur ekki heimildir til að skoða hana. Biddu sendandann um að deila henni.",
    "No search results for “{query}”" : "Engar leitarniðurstöður fyrir “{query}”",
    "Search for files" : "Leita að skrám",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Leyfa að takmarka skráaheiti til að tryggja að hægt sé að samstilla skrár við öll biðlaraforrit. Sjálfgefið eru leyfð öll skráaheiti sem gilda á POSIX (þ.e.a.s. Linux eða macOS).",
    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Eftir að Windows-samhæfð skráaheiti hafa verið virkjuð, er ekki lengur hægt að breyta fyrirliggjandi skrám, en þær getur eigandi þeirra samt endurnefnt með gildu skráaheiti.",
    "Failed to toggle Windows filename support" : "Tókst ekki að víxla stuðningi við Windows-skráaheiti af/á",
    "Files compatibility" : "Samhæfni skráa",
    "Enforce Windows compatibility" : "Þvinga fram samhæfni við Windows",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Þetta mun útiloka skráaheiti sem ekki gilda á Windows-kerfum, eins og þau sem innihalda frátekin heiti og sérstafi. En þetta mun hinsvegar ekki þvinga fram samhæfni í stafstöðu (há-/lágstafir).",
    "Blank" : "Tóm",
    "Unable to create new file from template" : "Tekst ekki að búa til nýja skrá út frá sniðmáti",
    "Pick a template for {name}" : "Veldu sniðmát fyrir {name}",
    "Create a new file with the selected template" : "Búa til nýja skrá úr völdu sniðmáti",
    "Creating file" : "Bý til skrá",
    "Save as {displayName}" : "Vista sem {displayName}",
    "Save as …" : "Vista sem …",
    "Converting files …" : "Umbreyti skrám …",
    "Failed to convert files: {message}" : "Mistókst að umbreyta skrám: {message}",
    "All files failed to be converted" : "Mistókst að umbreyta öllum skrám",
    "One file could not be converted: {message}" : "Ekki var hægt að umbreyta einni skrá: {message}",
    "Failed to convert files" : "Mistókst að umbreyta skrám",
    "Converting file …" : "Umbreyti skrá…",
    "File successfully converted" : "Tókst að umbreyta skrá",
    "Failed to convert file: {message}" : "Mistókst að umbreyta skrá: {message}",
    "Failed to convert file" : "Mistókst að umbreyta skrá",
    "Delete" : "Eyða",
    "Leave this share" : "Yfirgefa þessa sameign",
    "Leave these shares" : "Yfirgefa þessar sameignir",
    "Disconnect storage" : "Aftengja geymslu",
    "Disconnect storages" : "Aftengja geymslurými",
    "Delete permanently" : "Eyða varanlega",
    "Delete and unshare" : "Eyða og hætta deilingu",
    "Delete file" : "Eyða skrá",
    "Delete files" : "Eyða skrám",
    "Delete folder" : "Eyða möppu",
    "Delete folders" : "Eyða möppum",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Þú ert við það að eyða endanlega {count} atriði","Þú ert við það að eyða endanlega {count} atriðum"],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Þú ert við það að eyða {count} atriði","Þú ert við það að eyða {count} atriðum"],
    "Confirm deletion" : "Staðfesta eyðingu",
    "Cancel" : "Hætta við",
    "Download" : "Niðurhal",
    "The requested file is not available." : "Umbeðin skrá er ekki tiltæk.",
    "The requested files are not available." : "Umbeðnar skrár eru ekki tiltækar.",
    "Add to favorites" : "Bæta í eftirlæti",
    "Remove from favorites" : "Fjarlægja úr eftirlætum",
    "Add or remove favorite" : "Bæta við eða fjarlægja eftirlæti",
    "Moving \"{source}\" to \"{destination}\" …" : "Færi \"{source}\" í \"{destination}\" …",
    "Copying \"{source}\" to \"{destination}\" …" : "Afrita \"{source}\" í \"{destination}\" …",
    "Destination is not a folder" : "Áfangastaðurinn er ekki mappa",
    "This file/folder is already in that directory" : "Þessi skrá/mappa er þegar í þessari möppu",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Þú getur ekki flutt skrá/möppu inn í sjálfa sig eða inni í undirmöppu af sjálfri sér",
    "(copy)" : "(afrita)",
    "(copy %n)" : "(afrita %n)",
    "A file or folder with that name already exists in this folder" : "Skrá eða mappa með þessu heiti er þegar til staðar í þessari möppu",
    "The files are locked" : "Skrárnar eru læstar",
    "The file does not exist anymore" : "Skráin  er ekki lengur til",
    "Choose destination" : "Veldu áfangastað",
    "Copy to {target}" : "Afrita í {target}",
    "Copy" : "Afrita",
    "Move to {target}" : "Færa í {target}",
    "Move" : "Færa",
    "Move or copy operation failed" : "Aðgerð við að færa eða afrita mistókst",
    "Move or copy" : "Færa eða afrita",
    "Open folder" : "Opna möppu",
    "Open folder {displayName}" : "Opna möppu {displayName}",
    "Open in Files" : "Opna í skráaforritinu",
    "Open locally" : "Opna staðvært",
    "Failed to redirect to client" : "Mistókst að endurbeina til biðlara",
    "Open file locally" : "Opna skrá staðvært",
    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Skráin ætti núna að opnast á tækinu þínu. Ef það gerist ekki, ættirðu að ganga úr skugga um að þú sért með vinnutölvuforritið uppsett.",
    "Retry and close" : "Prófa aftur og loka",
    "Open online" : "Opna á netinu",
    "Rename" : "Endurnefna",
    "Details" : "Nánar",
    "View in folder" : "Skoða í möppu",
    "Today" : "Í dag",
    "Last 7 days" : "Síðustu 7 daga",
    "Last 30 days" : "Síðustu 30 daga",
    "This year ({year})" : "Þetta ár ({year})",
    "Last year ({year})" : "Síðasta ár ({year})",
    "Documents" : "Skjöl",
    "Spreadsheets" : "Töflureiknar",
    "Presentations" : "Kynningar",
    "PDFs" : "PDF-skrár",
    "Folders" : "Möppur",
    "Audio" : "Hljóð",
    "Images" : "Myndir",
    "Videos" : "Myndskeið",
    "Created new folder \"{name}\"" : "Bjó til nýja möppu \"{name}\"",
    "Unable to initialize the templates directory" : "Tókst ekki að frumstilla sniðmátamöppuna",
    "Create templates folder" : "Búa til sniðmátamöppu",
    "Templates" : "Sniðmát",
    "New template folder" : "Ný mappa fyrir sniðmát",
    "In folder" : "Í möppunni",
    "Search in all files" : "Leita í öllum skrám",
    "Search in folder: {folder}" : "Leita í möppunni: {folder}",
    "One of the dropped files could not be processed" : "Ekki var hægt að vinna með eina af slepptu skránum",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Vafrinn þinn styður ekki API skráakerfis. Möppur verða ekki sendar inn",
    "No files to upload" : "Engar skrár til að senda inn",
    "Unable to create the directory {directory}" : "Get ekki búið til möppuna {directory}",
    "Some files could not be uploaded" : "Ekki tókst að senda inn sumar skrár",
    "Files uploaded successfully" : "Tókst að senda inn skrár",
    "No files to process" : "Engar skrár til að vinna úr",
    "Some files could not be copied" : "Ekki tókst að afrita sumar skrár",
    "Some files could not be moved" : "Ekki tókst að færa sumar skrár",
    "Files copied successfully" : "Tókst að afrita skrár",
    "Files moved successfully" : "Tókst að færa skrár",
    "Conflicts resolution skipped" : "Sleppti lausn árekstra",
    "Upload cancelled" : "Hætt við innsendingu",
    "Could not rename \"{oldName}\", it does not exist any more" : "Gat ekki endurnefnt \"{oldName}\", það er ekki lengur til staðar",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Heitið \"{newName}\" er nú þegar notað í \"{dir}\" möppunni. Veldu eitthvað annað nafn.",
    "Could not rename \"{oldName}\"" : "Tókst ekki að endurnefna \"{oldName}\"",
    "This operation is forbidden" : "Þessi aðgerð er bönnuð",
    "This folder is unavailable, please try again later or contact the administration" : "Þessi mappa er ekki aðgengileg, reyndu aftur síðar eða hafðu samband við kerfisstjórnendur",
    "Storage is temporarily not available" : "Gagnageymsla ekki tiltæk í augnablikinu",
    "Unexpected error: {error}" : "Óvænt villa: {error}",
    "_%n file_::_%n files_" : ["%n skrá","%n skrár"],
    "_%n folder_::_%n folders_" : ["%n mappa","%n möppur"],
    "_%n hidden_::_%n hidden_" : ["%n falin","%n faldar"],
    "Filename must not be empty." : "Skráarheiti má ekki vera tómt.",
    "\"{char}\" is not allowed inside a filename." : "\"{char}\" er er ekki leyfilegt innan í skráarheiti.",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" er frátekið heiti og er ekki leyft í skráaheitum.",
    "\"{extension}\" is not an allowed filetype." : "\"{extension}\" er ekki leyfileg skráartegund.",
    "Filenames must not end with \"{extension}\"." : "Skráaheiti mega ekki enda á \"{extension}\".",
    "List of favorite files and folders." : "Listi yfir eftirlætisskrár og möppur.",
    "No favorites yet" : "Engin eftirlæti ennþá",
    "Files and folders you mark as favorite will show up here" : "Skrár og möppur sem þú merkir sem eftirlæti birtast hér",
    "List of your files and folders." : "Listi yfir skrárnar þínar og möppur.",
    "Folder tree" : "Möppugreinar",
    "List of your files and folders that are not shared." : "Listi yfir skrárnar þínar og möppur sem ekki er deilt.",
    "No personal files found" : "Engar einkaskrár fundust",
    "Files that are not shared will show up here." : "Skrár sem ekki er deilt birtast hér.",
    "Recent" : "Nýlegt",
    "List of recently modified files and folders." : "Listi yfir nýlega breyttar skrár og möppur.",
    "No recently modified files" : "Engar nýlega breyttar skrár",
    "Files and folders you recently modified will show up here." : "Skrár og möppur sem þú breyttir nýlega birtast hér.",
    "Search" : "Search",
    "Search results within your files." : "Leitarniðurstöður úr skránum þínum.",
    "No entries found in this folder" : "Engar skrár fundust í þessari möppu",
    "Select all" : "Velja allt",
    "Upload too large" : "Innsend skrá er of stór",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Skrárnar sem þú ert að senda inn eru stærri en hámarks innsendingarstærð á þessum netþjóni.",
    "%1$s (renamed)" : "%1$s (endurnefnd)",
    "renamed file" : "endurnefndi skrá",
    "Upload (max. %s)" : "Senda inn (hám. %s)",
    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Eftir að Windows-samhæfð skráaheiti hafa verið virkjuð, er ekki lengur hægt að breyta fyrirliggjandi skrám, en þær getur eigandi þeirra samt endurnefnt með gildu skráaheiti.",
    "\"{displayName}\" failed on some elements" : "\"{displayName}\" mistókst á einhverjum atriðum",
    "\"{displayName}\" batch action executed successfully" : "Tókst að framkvæma \"{displayName}\" magnvinnsluaðgerð",
    "\"{displayName}\" action failed" : "\"{displayName}\" aðgerð mistókst",
    "Submitting fields …" : "Sendi inn gagnasvið…",
    "\"{displayName}\" action executed successfully" : "Tókst að framkvæma \"{displayName}\" aðgerð",
    "Filter file names …" : "Sía skráaheiti …",
    "Clipboard is not available" : "Klippispjald er ekki tiltækt",
    "WebDAV URL copied to clipboard" : "WebDAV-slóð afrituð á klippispjaldið",
    "Enable the grid view" : "Virkja reitasýnina",
    "Enable folder tree" : "Virkja möppugreinar",
    "WebDAV" : "WebDAV",
    "Copy to clipboard" : "Afrita á klippispjald",
    "Use this address to access your Files via WebDAV" : "Notaðu þetta vistfang til að nálgast skráaforritið þitt með WebDAV",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Ef þú hefur virkjað 2FA tveggja-þrepa-auðkenningu, þarftu að útbúa nýtt lykilorð forrits og nota það með því að smella hér.",
    "Show a warning dialog when changing a file extension." : "Birta aðvörunarglugga þegar skráarendingu er breytt.",
    "Keyboard shortcuts" : "Flýtileiðir á lyklaborði",
    "Speed up your Files experience with these quick shortcuts." : "Flýttu fyrir vinnu þinni með skrár með þessum flýtilyklum.",
    "Open the actions menu for a file" : "Opna aðgerðavalmynd fyrir skrá",
    "Rename a file" : "Endurnefna skrá",
    "Delete a file" : "Eyða skrá",
    "Favorite or remove a file from favorites" : "Setja skrá í eða fjarlægja úr eftirlætum",
    "Manage tags for a file" : "Sýsla með merki fyrir skrá",
    "Deselect all files" : "Afvelja allar skrár",
    "Select or deselect a file" : "Velja eða afvelja skrá",
    "Select a range of files" : "Velja svið skráa",
    "Navigate to the parent folder" : "Fara í yfirmöppuna",
    "Navigate to the file above" : "Fara á skrána fyrir ofan",
    "Navigate to the file below" : "Fara á skrána fyrir neðan",
    "Navigate to the file on the left (in grid mode)" : "Fara á skrána til vinstri (í reitayfirliti)",
    "Navigate to the file on the right (in grid mode)" : "Fara á skrána til hægri (í reitayfirliti)",
    "Toggle the grid view" : "Víxla reitayfirliti af/á",
    "Open the sidebar for a file" : "Opna hliðarspjald fyrir skrá",
    "You" : "Þú",
    "Shared multiple times with different people" : "Deilt mörgum sinnum með mismunandi fólki",
    "Unable to change the favorite state of the file" : "Get ekki breytt stöðu sem eftirlæti á skránni",
    "Error while loading the file data" : "Villa við að hlaða inn skráagögnum",
    "Tags" : "Merki",
    "Save as …" : "Vista sem …",
    "Converting files …" : "Umbreyti skrám …",
    "Converting file …" : "Umbreyti skrá…",
    "Deletion cancelled" : "Hætt við eyðingu",
    "Edit locally" : "Breyta staðvært",
    "Moving \"{source}\" to \"{destination}\" …" : "Færi \"{source}\" í \"{destination}\" …",
    "Copying \"{source}\" to \"{destination}\" …" : "Afrita \"{source}\" í \"{destination}\" …",
    "Move cancelled" : "Hætt við tilfærslu",
    "Cancelled move or copy of \"{filename}\"." : "Hætti við aðgerð við að færa eða afrita \"{filename}\".",
    "Cancelled move or copy operation" : "Hætti við aðgerð við að færa eða afrita",
    "Open details" : "Opna nánari upplýsingar",
    "Photos and images" : "Myndefni",
    "New folder creation cancelled" : "Hætti við gerð nýrrar möppu",
    "This directory is unavailable, please check the logs or contact the administrator" : "Þessi mappa er ekki tiltæk, athugaðu atvikaskrár eða hafðu samband við kerfissjóra",
    "All folders" : "Allar möppur",
    "Search everywhere …" : "Leita allsstaðar …",
    "Search here …" : "Leita hér …",
    "Preparing …" : "Undirbý …"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
